==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PolarScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
import { PolarScatterSeriesDescription } from "./PolarScatterSeriesDescription";
/**
 * @hidden
 */
export let PolarScatterSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarScatterSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarScatterSeriesDescriptionMetadata.a == null) {
                PolarScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarScatterSeriesDescriptionMetadata.c(PolarScatterSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarScatterSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(PolarScatterSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            PolarScatterSeriesDescriptionMetadata.b(a);
            a.ad("PolarScatterSeries", () => new PolarScatterSeriesDescription());
            a.ac("PolarScatterSeries", PolarScatterSeriesDescriptionMetadata.a);
        }
    }
    PolarScatterSeriesDescriptionMetadata.$t = markType(PolarScatterSeriesDescriptionMetadata, 'PolarScatterSeriesDescriptionMetadata');
    PolarScatterSeriesDescriptionMetadata.a = null;
    return PolarScatterSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PolarScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
import { PolarScatterSeriesDescription } from "./PolarScatterSeriesDescription";
/**
 * @hidden
 */
export let PolarScatterSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarScatterSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarScatterSeriesDescriptionMetadata.a == null) {
                PolarScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarScatterSeriesDescriptionMetadata.c(PolarScatterSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarScatterSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(PolarScatterSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            PolarScatterSeriesDescriptionMetadata.b(a);
            a.ae("PolarScatterSeries", () => new PolarScatterSeriesDescription());
            a.ad("PolarScatterSeries", PolarScatterSeriesDescriptionMetadata.a);
        }
    }
    PolarScatterSeriesDescriptionMetadata.$t = markType(PolarScatterSeriesDescriptionMetadata, 'PolarScatterSeriesDescriptionMetadata');
    PolarScatterSeriesDescriptionMetadata.a = null;
    return PolarScatterSeriesDescriptionMetadata;
})();
